@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_reloc.c 1.1 Wed, 25 Aug 1999 16:26:49 +1000 keith $"
+#ident "$Id: obj_reloc.c 1.2 Fri, 08 Oct 1999 16:20:06 +1000 keith $"
 
 #include <string.h>
 #include <assert.h>
@@ -217,7 +217,7 @@ obj_allocate_commons(struct obj_file *f)
       struct obj_section *s = f->sections[i];
       if (s->header.sh_type == SHT_NOBITS)
 	{
-	  if (s->header.sh_size)
+	  if (s->header.sh_size || 1)    /*KAO*/
 	    s->contents = memset(xmalloc(s->header.sh_size),
 				 0, s->header.sh_size);
 	  else
